@@ -12,7 +12,6 @@
 
 #include "../../core/cog.h"
 #include "../common/cog-gl-utils.h"
-#include "../common/egl-proc-address.h"
 #include "cog-gtk-settings-dialog.h"
 
 #define DEFAULT_WIDTH 1280
@@ -643,6 +642,12 @@ shell_device_factor_changed(CogShell *shell, GParamSpec *param_spec, gpointer da
     window->device_scale_factor = cog_shell_get_device_scale_factor(shell);
 }
 
+static struct wpe_view_backend *
+gamepad_provider_get_view_backend_for_gamepad(void *provider G_GNUC_UNUSED, void *gamepad G_GNUC_UNUSED)
+{
+    return wpe_view_backend_exportable_fdo_get_view_backend(win.exportable);
+}
+
 static gboolean
 cog_gtk4_platform_setup(CogPlatform *platform, CogShell *shell, const char *params, GError **error)
 {
@@ -659,6 +664,7 @@ cog_gtk4_platform_setup(CogPlatform *platform, CogShell *shell, const char *para
 
     setup_window(&win);
     setup_fdo_exportable(&win);
+    cog_gamepad_setup(gamepad_provider_get_view_backend_for_gamepad);
 
 #if HAVE_FULLSCREEN_HANDLING
     wpe_view_backend_set_fullscreen_handler(webkit_web_view_backend_get_wpe_backend(win.view_backend),
